import thunder
from thunder.utils.context import ThunderContext

tsc = ThunderContext(sc)

print('\n')
print('Running thunder version ' + thunder.__version__)
print('A thunder context is available as tsc')